"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const definition_1 = require("../common/definition");
const commonFlags = require("../common/flags");
class Info extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Info);
        const definition = definition_1.resolveDefinition(args.definition);
        if (!definition) {
            this.error('Please load a definition file', { exit: 1 });
        }
        let document;
        try {
            document = await definition_1.parseDefinition({ definition });
        }
        catch (err) {
            this.error(err, { exit: 1 });
        }
        this.log(`Loaded: ${definition}`);
        this.log();
        definition_1.printInfo(document, this);
        if (flags.operations) {
            this.log();
            definition_1.printOperations(document, this);
        }
        if (flags.schemas) {
            this.log();
            definition_1.printSchemas(document, this);
        }
    }
}
Info.description = 'print information about definition file';
Info.examples = [
    '$ openapi info https://raw.githubusercontent.com/OAI/OpenAPI-Specification/master/examples/v3.0/petstore.yaml',
    `$ openapi info ./openapi.yml`,
];
Info.flags = Object.assign({}, commonFlags.help(), { operations: command_1.flags.boolean({ description: 'list operations in document', default: true, allowNo: true }), schemas: command_1.flags.boolean({ description: 'list schemas in document', default: false, allowNo: true }) });
Info.args = [
    {
        name: 'definition',
        description: 'input definition file',
    },
];
exports.default = Info;
